@@ -89,22 +89,21 @@ def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que
   #Código para actualizar valores: if isinstance(element[1], sy.Expr):element = [element[0],element[1].subs(c_componente[0],c_componente[1])]
 
 
-def E(expr,color = "red"):
-  DataRealSymbolList = []#Guarda en formato symbolo todos los Datos
-  for element in DatosList:
-    if (element[1] != None) :
-      word = "" #if isinstance(element[1],sy.Float) or isinstance(element[1],float) or isinstance(element[1],int) or isinstance(element[1],sy.core.numbers.Integer):
-      for letra in sympy.latex(Redondear(element[1])):
-        if letra == " ":
-          word = word+"~"
-        else:
-          word = word+letra
-      DataRealSymbolList.append([element[0],sympy.symbols("("+word+")")])
-    else:
-      #Es decir, si es un simbolo sin valor (None) o coleccion de simbolos. Entonces:
-      DataRealSymbolList.append([element[0],element[0]])
-  #display(DataRealSymbolList)
-
+#def E(expr,color = "red"):
+#  DataRealSymbolList = []#Guarda en formato symbolo todos los Datos
+#  for element in DatosList:
+#    if (element[1] != None) :
+#      word = "" #if isinstance(element[1],sy.Float) or isinstance(element[1],float) or isinstance(element[1],int) or isinstance(element[1],sy.core.numbers.Integer):
+#      for letra in sympy.latex(Redondear(element[1])):
+#        if letra == " ":
+#          word = word+"~"
+#        else:
+#          word = word+letra
+#      DataRealSymbolList.append([element[0],sympy.symbols("("+word+")")])
+#    else:
+#      #Es decir, si es un simbolo sin valor (None) o coleccion de simbolos. Entonces:
+#      DataRealSymbolList.append([element[0],element[0]])
+#  #display(DataRealSymbolList)
 
   if isinstance(expr,sympy.core.relational.Equality):
     texto = sympy.latex(expr)
@@ -143,19 +142,19 @@ def S(c_componente):#Guardar
   else:
     D(c_componente,"red")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
 
-def A(c_componente):#Actualizar
-  color = "red"
-  for element in DatosList:
-    if element[0] == c_componente[0]:
-      #Identificamos el componente en la lista de datos guardados
-      #Ahora actualizamos los valores
-      D(c_componente)
-      E([c_componente[0],c_componente[1]],color)
-      D([c_componente[0],c_componente[1].subs(DatosList)],color)
-      #D([c_componente[0],E(c_componente[1])],color)
-      #D([c_componente[0],element[1].subs(DatosList)],color)
-      element[1] = element[1].subs(DatosList)
-      return element#Sistema por Artemio Araya :)
+#def A(c_componente):#Actualizar
+#  color = "red"
+#  for element in DatosList:
+#    if element[0] == c_componente[0]:
+#      #Identificamos el componente en la lista de datos guardados
+#      #Ahora actualizamos los valores
+#      D(c_componente)
+#      E([c_componente[0],c_componente[1]],color)
+#      D([c_componente[0],c_componente[1].subs(DatosList)],color)
+#      #D([c_componente[0],E(c_componente[1])],color)
+#      #D([c_componente[0],element[1].subs(DatosList)],color)
+#      element[1] = element[1].subs(DatosList)
+#      return element#Sistema por Artemio Araya :)
 
 def R(string):
   display(IPython.display.Latex(string))  
